Exception: Eluvia::Errors::Forbidden

Inherits:
StandardError show all
Defined in:
lib/eluvia/errors/forbidden.rb

Instance Attribute Summary

Attributes inherited from StandardError

#error, #message, #no_sentry, #source, #status, #timestamp

Instance Method Summary collapse

Methods inherited from StandardError

#to_h, #to_s

Constructor Details

#initialize(message = nil) ⇒ Forbidden

Returns a new instance of Forbidden.



5
6
7
8
9
10
11
12
13
# File 'lib/eluvia/errors/forbidden.rb', line 5

def initialize(message = nil)
  super(
    message || "The request contained valid data and was understood by the server, but the server is refusing action.",
    "Forbidden",
    403,
    nil,
    false
  )
end