Exception: Eluvia::Errors::Unauthorized

Inherits:
StandardError show all
Defined in:
lib/eluvia/errors/unauthorized.rb

Instance Attribute Summary

Attributes inherited from StandardError

#error, #message, #no_sentry, #source, #status, #timestamp

Instance Method Summary collapse

Methods inherited from StandardError

#to_h, #to_s

Constructor Details

#initialize(message = nil, no_sentry = false) ⇒ Unauthorized

Returns a new instance of Unauthorized.



5
6
7
8
9
10
11
12
13
# File 'lib/eluvia/errors/unauthorized.rb', line 5

def initialize(message = nil, no_sentry = false)
  super(
    message || "Similar to 403 Forbidden, but specifically for use when authentication is required and has failed or has not yet been provided.",
    "Unauthorized",
    401,
    nil,
    no_sentry
  )
end