Exception: Eluvia::Errors::Forbidden
- Inherits:
-
StandardError
- Object
- StandardError
- StandardError
- Eluvia::Errors::Forbidden
- Defined in:
- lib/eluvia/errors/forbidden.rb
Instance Attribute Summary
Attributes inherited from StandardError
#error, #message, #no_sentry, #source, #status, #timestamp
Instance Method Summary collapse
-
#initialize(message = nil) ⇒ Forbidden
constructor
A new instance of Forbidden.
Methods inherited from StandardError
Constructor Details
#initialize(message = nil) ⇒ Forbidden
Returns a new instance of Forbidden.
5 6 7 8 9 10 11 12 13 |
# File 'lib/eluvia/errors/forbidden.rb', line 5 def initialize( = nil) super( || "The request contained valid data and was understood by the server, but the server is refusing action.", "Forbidden", 403, nil, false ) end |