Exception: Eluvia::Errors::Unauthorized
- Inherits:
-
StandardError
- Object
- StandardError
- StandardError
- Eluvia::Errors::Unauthorized
- Defined in:
- lib/eluvia/errors/unauthorized.rb
Instance Attribute Summary
Attributes inherited from StandardError
#error, #message, #no_sentry, #source, #status, #timestamp
Instance Method Summary collapse
-
#initialize(message = nil, no_sentry = false) ⇒ Unauthorized
constructor
A new instance of Unauthorized.
Methods inherited from StandardError
Constructor Details
#initialize(message = nil, no_sentry = false) ⇒ Unauthorized
Returns a new instance of Unauthorized.
5 6 7 8 9 10 11 12 13 |
# File 'lib/eluvia/errors/unauthorized.rb', line 5 def initialize( = nil, no_sentry = false) super( || "Similar to 403 Forbidden, but specifically for use when authentication is required and has failed or has not yet been provided.", "Unauthorized", 401, nil, no_sentry ) end |